<?php
class Noticias_Newswire_Feed_Cached_Repository extends Noticias_Newswire_Feed_Repository
{
    public function get_feeds($url)
    {
        $this->delete_cache_files();
        $file_path = $this->get_file_path($url);
        $valid_cache_file = $this->is_valid_cache_file($file_path);
        if (!$valid_cache_file) {
            $json = parent::get_feeds($url);
            if ($json != '[]') $this->put($url, $json);
            return $json;
        }
        $json = $this->get($url);
        return $json;
    }

    private function delete_cache_files()
    {
        $cache_directory = Noticias_Newswire_Common::get_cache_directory();
        $handle = opendir($cache_directory);
        if (!$handle) {
            return;
        }
        while (($file = readdir($handle)) !== false) {
            $file_path = $cache_directory . DIRECTORY_SEPARATOR . $file;
            if (!$this->is_valid_cache_file($file_path)) {
                Noticias_Newswire_Common::remove_file($file_path);
            }
        }
        closedir($handle);
    }

    private function is_valid_cache_file($file_path)
    {
        if (!is_file($file_path)) {
            return false;
        }
        $last_modified_timestamp = filemtime($file_path);
        $hours_elapsed = Noticias_Newswire_Common::get_hours_elapsed_decimal($last_modified_timestamp);
        $max_hours = round(NNW_CACHE_HOURS, 2);
        return $hours_elapsed <= $max_hours;
    }

    private function get_file_path($url)
    {
        $api_url = NNW_API_URL . "?";
        $file_name = str_replace($api_url, "", strtolower($url));
        $file_name = md5($file_name);
        $file_path = Noticias_Newswire_Common::get_cache_directory() . DIRECTORY_SEPARATOR . $file_name . ".json";
        return $file_path;
    }

    private function get($url)
    {
        $json = FALSE;
        $file_path = $this->get_file_path($url);
        if (!is_file($file_path)) {
            return FALSE;
        }
        try {
            $content = file_get_contents($file_path);
            if ($content !== FALSE) {
                $json = $content;
            }
        } catch (Exception $ex) {
            return FALSE;
        }
        return $json;
    }

    private function put($url, $json)
    {
        if (empty($json) || $json == FALSE) {
            return FALSE;
        }
        $cache_directory = Noticias_Newswire_Common::get_cache_directory();
        Noticias_Newswire_Common::make_directory($cache_directory);
        if (!is_dir($cache_directory)) {
            return FALSE;
        }
        $file_path = $this->get_file_path($url);
        try {
            file_put_contents($file_path, $json);
            clearstatcache();
        } catch (Exception $ex) {
            return FALSE;
        }
    }
}
