<?php

/**
 * Plugin Name: Noticias Newswire
 * Plugin URI: https://www.noticiasnewswire.com/placements
 * Description: List all news from noticiasnewswire.com in html format.
 * Version: 2.0.2
 * Author: Noticias Newswire
 * Author URI: https://www.noticiasnewswire.com/placements
 * Requires at least: 4.7
 * Tested up to: 5.8.1
 */

if (!defined('ABSPATH')) exit;

add_action('template_redirect', 'do_noticiasnewswire_redirect');

function do_noticiasnewswire_redirect()
{
	$permalink = strtolower($_SERVER['REQUEST_URI']);
	$searchHW = '/hispanicize-wire-news';
	$posHW = strpos($permalink, $searchHW);
	$replace = '/noticias-newswire';
	if ($posHW !== FALSE) {
		$permalink = str_replace($searchHW, $replace, $permalink);
		if (wp_safe_redirect($permalink, 301)) {
			die();
		}
	}
	$searchLX = '/latinx-newswire';
	$posLX = strpos($permalink, $searchLX);
	if ($posLX !== FALSE) {
		$permalink = str_replace($searchLX, $replace, $permalink);
		if (wp_safe_redirect($permalink, 301)) {
			die();
		}
	}
}

// Include plugin class files
require_once('noticias-newswire-common.php');
require_once('noticias-newswire-settings.php');
require_once('noticias-newswire-post.php');
require_once('noticias-newswire-feed.php');
require_once('noticias-newswire-feed-repository.php');
require_once('noticias-newswire-feed-cached-repository.php');

$noticias_newswire_feed;
if (seo_hma_is_post_detail()) {
	$noticias_newswire_feed = new Noticias_Newswire_Feed(NNW_API_URL . '?post=' . $_GET['l'] . '&show_desc=yes');
	if (count($noticias_newswire_feed->posts) == 0) {
		$noticias_newswire_feed = new Noticias_Newswire_Feed(NNW_API_URL . '?post=' . $_GET['l'] . '&show_desc=yes&lang=es');
	}
}

add_action('init', function () {
	add_action('wp_loaded', 'seo_hma_buffer_start');
	add_action('shutdown', 'seo_hma_buffer_end');
}, 25);

function seo_hma_buffer_start()
{
	ob_start("seo_hma_callback");
}

function seo_hma_buffer_end()
{
	ob_end_flush();
}

function seo_hma_callback($output)
{
	global $noticias_newswire_feed;
	if (seo_hma_is_post_detail()) {
		$postTitle = '';
		$postMetaDescription = '';
		foreach ($noticias_newswire_feed->posts as $post) {
			$postTitle = $post->title;
			$postMetaDescription = $post->summary;
		}
		$output = seo_hma_remove_tag($output, '<h1 class="entry-title', '</h1>');
		$output = seo_hma_remove_tag($output, '<link rel="canonical"', '/>');
		$output = seo_hma_change_tag($output, $postTitle, '<title>', '</title>');
		$output = seo_hma_change_tag($output, $postTitle . '" ', '<meta property="og:title" content="', '/>');
		$output = seo_hma_change_tag($output, $postTitle . '" ', '<meta name="twitter:title" content="', '/>');
		$output = seo_hma_change_tag($output, $postMetaDescription . '" ', '<meta property="og:description" content="', '/>');
		$output = seo_hma_change_tag($output, $postMetaDescription . '" ', '<meta name="description" content="', '/>');
		return $output;
	}
	if (seo_hma_is_noticias_page()) {
		$output = seo_hma_remove_tag($output, '<link rel="canonical"', '/>');
		return $output;
	}
	return $output;
}

function seo_hma_remove_tag($output, $startTag, $endTag)
{
	$startPos = strpos($output, $startTag);
	if ($startPos !== false) {
		$endPos = strpos($output, $endTag, $startPos);
		if ($endPos !== false) {
			$tag = substr($output, $startPos, ($endPos - $startPos) + strlen($endTag));
			$output = str_replace($tag, '', $output);
		}
	}
	return $output;
}

function seo_hma_change_tag($output, $value, $startTag, $endTag)
{
	$startPos = strpos($output, $startTag);
	if ($startPos !== false) {
		$endPos = strpos($output, $endTag, $startPos);
		if ($endPos !== false) {
			$tag = substr($output, $startPos, ($endPos - $startPos) + strlen($endTag));
			$value = $startTag . $value . $endTag;
			$output = str_replace($tag, $value, $output);
		}
	}
	return $output;
}

function seo_hma_is_post_detail()
{
	$uri = $_SERVER['REQUEST_URI'];
	$pos = strpos($uri, '/noticias-newswire/?l=');
	return $pos !== false;
}

function seo_hma_is_noticias_page()
{
	$uri = $_SERVER['REQUEST_URI'];
	$pos = strpos($uri, '/noticias-newswire');
	return $pos !== false;
}

/**
 * Returns the main instance of Noticias_Newswire_News to prevent the need to use globals.
 *
 * @since  2.0.2
 * @return object Noticias_Newswire
 */
function Noticias_Newswire()
{
	$instance = Noticias_Newswire_Plugin::instance(__FILE__, '2.0.2');
	if (is_null($instance->settings)) {
		$instance->settings = Noticias_Newswire_Settings::instance($instance);
	}
	return $instance;
}

Noticias_Newswire();

class Noticias_Newswire_Plugin
{
	/**
	 * The single instance of Noticias_Newswire_Plugin.
	 * @var     object
	 * @access  private
	 * @since   2.0.2
	 */
	private static $_instance = null;

	/**
	 * Settings class object
	 * @var     object
	 * @access  public
	 * @since   2.0.2
	 */
	public $settings = null;

	/**
	 * The version number.
	 * @var     string
	 * @access  public
	 * @since   2.0.2
	 */
	public $_version;

	/**
	 * The token.
	 * @var     string
	 * @access  public
	 * @since   2.0.2
	 */
	public $_token;

	/**
	 * Noticias Newswire URL
	 * @var string
	 * @access public
	 */
	public $noticiasnewswire_url = NNW_API_URL;

	/**
	 * Noticias Newswire Domain
	 * @var string
	 * @access public
	 */
	public $noticiasnewswire_domain = NNW_DOMAIN;

	/**
	 * The title
	 * @var     string
	 * @access  public
	 * @since   2.0.2
	 */
	public $noticiasnewswire_title = '';

	/**
	 * Constructor function.
	 * @access  public
	 * @since   2.0.2
	 * @return  void
	 */
	public function __construct($file = '', $version = '2.0.2')
	{
		$this->_version = $version;
		$this->_token = 'noticias_newswire';
		$this->file = $file;
		$this->dir = dirname($this->file);
		$this->assets_dir = trailingslashit($this->dir) . 'assets';
		$this->assets_url = esc_url(trailingslashit(plugins_url('/assets/', $this->file)));
		// Load frontend JS & CSS
		add_action('wp_enqueue_scripts', array($this, 'enqueue_styles'), 10);
		add_action('wp_enqueue_scripts', array($this, 'enqueue_scripts'), 10);
		// Load admin JS & CSS
		add_action('admin_enqueue_scripts', array($this, 'admin_enqueue_scripts'), 10, 1);
		add_action('admin_enqueue_scripts', array($this, 'admin_enqueue_styles'), 10, 1);
		add_shortcode('noticias-newswire', array($this, 'Noticias_Newswire_Display'));
		$index_req = 0;
		if (!empty($_GET['i'])) {
			$index_req = $_GET['i'];
		} // i = index of any post.. to see any specific post entry		
		if ($index_req != 0) {
			add_filter('wp_title', array($this, 'get_noticiasnewswire_title'), 100, 1);
		}
	}

	/**
	 * List all Noticias Newswire News.
	 * @return string
	 */
	public function Noticias_Newswire_Display($atts)
	{
		$atts = shortcode_atts(array(
			'logo' => 'No',
			'title' => 'Noticias Newswire',
			'language' => 'en',
			'category' => '',
			'thumbnail' => 'Yes',
			'num_posts' => 3,
			'post_date' => 'Yes',
			'widget_size' => '',
			'widget_width' => '',
			'widget_height' => '',
			'widget_color' => '',
			'show_description' => 'Yes',
			'font' => 'inherit',
			'width' => 50,
			'mainpage' => '/noticias-newswire',
			'viewmore' => 'Yes',
			'pagination' => 'No',
			'target' => 'sidebar',
			'powered_by_title' => 'Feed Powered by Hispanic Market Advisors&#174;'
		), $atts, 'noticias-newswire');

		// Default value variables
		$index_req = 0;
		$post_index = 0;
		$location = '';
		$paged = 1;
		$logo = $atts['logo'];
		$title = $atts['title'];
		$language = $atts['language'];
		$category = $atts['category'];
		$thumbnail = 64;
		$has_thumbnail = (isset($atts['thumbnail']) && strtolower($atts['thumbnail']) != 'no') ? 'Yes' : 'No';
		$num_posts = $atts['num_posts'];
		$post_date = $atts['post_date'];
		$widget_size = $atts['widget_size'];
		$widget_width = $atts['widget_width'];
		$widget_height = $atts['widget_height'];
		$widget_color = $atts['widget_color'];
		$show_description = $atts['show_description'];
		$font = $atts['font'];
		$mainpage = $atts['mainpage'];
		$viewmore = $atts['viewmore'];
		$pagination = $atts['pagination'];
		$target = $atts['target'];
		$powered_by_title = $atts['powered_by_title'];
		$link_post = '';
		if (!empty($_GET['i'])) {
			$index_req = $_GET['i'];
		} // i = index of any post.. to see any specific post entry		
		if (!empty($_GET['pg'])) {
			$paged = $_GET['pg'];
		}	 // for pagination, pg contains the page to be seen
		if (!empty($_GET['l'])) {
			$link_post = $_GET['l'];
		}	 // for pagination, pg contains the page to be seen
		if ($target == 'sidebar') {
			$viewmore = 'Yes';
			$pagination = 'No';
		} else {
			$viewmore = 'No';
			$pagination = 'Yes';
		}
		if ($has_thumbnail == 'Yes') {
			$thumbnail = 64;
		} else {
			$thumbnail = 0;
		}
		$url_client = $mainpage;
		$url_client = str_ireplace("https://", "", $url_client);
		$url_client = str_ireplace("http://", "", $url_client);
		$url_client = str_ireplace("noticias-newswire", "", $url_client);
		$url_client = str_ireplace("www.", "", $url_client);
		$url_client = str_ireplace("/", "", $url_client);
		$query_string = '?paged=' . $paged . '&lang=' . $language . '&cat=' . $category . '&thumb_width=' . $thumbnail . '&urlclient=' . $url_client;
		$query_string .= '&post=' . $link_post . '&num_posts=' . $num_posts . '&post_date=' . $post_date . "&show_desc=" . $show_description;
		$noticias_newswire_feed = new Noticias_Newswire_Feed($this->noticiasnewswire_url . $query_string);
		$postsNumber = count($noticias_newswire_feed->posts);
		if ($postsNumber == 0) { // Not Found
			global $wp_query;
			$wp_query->set_404();
			status_header(404);
			get_template_part(404);
			exit();
		}
		// Building the page to be displayed
		$color_light = $this->get_light_color();
		$color_dark = $this->get_dark_color();
		$widget_style_size = '';
		if ($widget_size === '') {
			$widget_style_size = '';
		} elseif ($widget_size === 'custom') { // custom
			$widget_style_size = 'width:' . $widget_width . 'px;height:' . $widget_height . 'px;overflow:auto;';
		} elseif ($widget_size == '300x300') {
			$widget_style_size = 'width:300px;height:300px;overflow:auto;';
		} elseif ($widget_size == '300x550') {
			$widget_style_size = 'width:300px;height:550px;overflow:auto;';
		} elseif ($widget_size == '550x300') {
			$widget_style_size = 'width:550px;height:300px;overflow:auto;';
		}
		$widget_style = '';
		$widget_style_color = '';
		$title_color = 'color:inherit';
		if ($target == 'sidebar') { // only apply for Widget
			if ($widget_color === 'inherit') {
				$widget_style_color = '';
			} elseif ($widget_color === 'light') {
				$widget_style_color = 'background-color:' . $color_light . ';color:#000;';
			} elseif ($widget_color === 'dark') {
				$widget_style_color = 'background-color:' . $color_dark . ';color:#fff;';
				$title_color = 'color:#fff;';
			}
			if (($widget_style_size !== '') || ($widget_style_color !== '')) {
				$widget_style = ' style="' . $widget_style_size . $widget_style_color . '"; ';
			}
		}
		$return_value = '';
		ob_start(); ?>
		<div class="hw-widget-<?= $target . ' lxnw-widget-' . $target . ' nnw-widget-' . $target . '" ' . $widget_style ?>">
			<?php
			// ******************* if we must display the list of post entries *************************************
			if ($link_post == '' || $viewmore == "Yes") :
				if ($title !== "") :
					if ($logo == "Yes") :
						if ($target == 'sidebar' && $widget_color !== '') : ?>
							<div class=" hw-post-title-logo lxnw-post-title-logo nnw-post-title-logo" style="background:none;font-family:<?= $font ?>">
								<img src="https://www.noticiasnewswire.com/placements/logo.png" width="54px" /><?= $title ?>
							</div>
						<?php else : ?>
							<div class="hw-post-title-logo lxnw-post-title-logo nnw-post-title-logo" style="font-family:<?= $font ?>">
								<img src="https://www.noticiasnewswire.com/placements/logo.png" width="54px" /><?= $title ?>
							</div>
						<?php endif;
					else : ?>
						<div class="hw-post-title lxnw-post-title nnw-post-title" style="font-family:<?= $font ?>"><?= $title ?></div>
					<?php endif;
				else :
					if ($logo == "Yes") : ?>
						<div class="hw-post-title-logo lxnw-post-title-logo nnw-post-title-logo">
							<img src="https://www.noticiasnewswire.com/placements/logo.png" width="54px" />
						</div>
				<?php endif;
				endif; ?>
				<div class="hw-clear-both lxnw-clear-both nnw-clear-both"></div>
				<div class="hw-widget-body lxnw-widget-body nnw-widget-body">
					<?php
					foreach ($noticias_newswire_feed->posts as $post) :
						$post_index++;
						if ($post_index <= $num_posts) : ?>
							<div class="hw-post-entry lxnw-post-entry nnw-post-entry">
								<?php
								if ($show_description == "Yes") : ?>
									<h2 class="hw-post-link lxnw-post-link nnw-post-link">
										<a href="<?= $this->get_new_permalink($mainpage, $paged, $post_index, $post->link) ?>" style="font-family:<?= $font ?>;<?= $title_color ?>"><?= $post->title ?></a>
									</h2>
									<?php
									if ($post_date == "Yes") : ?>
										<div class="hw-post-date lxnw-post-date nnw-post-date" style="font-family:<?= $font ?>;"><?= $post->date ?></div>
									<?php
									endif;
									if ($thumbnail > 0) : ?>
										<div class="hw-post-thumb lxnw-post-thumb nnw-post-thumb"><?= $post->thumbnail ?></div>
									<?php endif; ?>
									<div class="hw-post-content lxnw-post-content nnw-post-content" style="font-family:<?= $font ?>;"><?= $post->summary ?></div>
									<?php else : // only head lines
									if ($thumbnail > 0) : ?>
										<div class="hw-post-thumb lxnw-post-thumb nnw-post-thumb"><?= $post->thumbnail ?></div>
									<?php endif; ?>
									<h2 class="hw-post-link lxnw-post-link nnw-post-link">
										<a href="<?= $this->get_new_permalink($mainpage, $paged, $post_index, $post->link) ?>" style="font-family:<?= $font ?>;<?= $title_color ?>"><?= $post->title ?></a>
									</h2>
									<?php
									if ($post_date == "Yes") : ?>
										<div class="hw-post-date lxnw-post-date nnw-post-date" style="font-family:<?= $font ?>;"><?= $post->date ?></div>
								<?php
									endif;
								endif; ?>
							</div>
							<div class="hw-clear-both lxnw-clear-both nnw-clear-both"></div>
							<hr />
						<?php
						endif;
					endforeach;
					if ($pagination == "Yes") :
						$prev = "Previous";
						$next = "Next";
						if ($language == "es") :
							$prev = "Anterior";
							$next = "Siguiente";
						endif;
						if ($paged > 1) : ?>
							<a class="button" href="<?= $mainpage ?>?pg=<?= ($paged - 1) ?>">&laquo; <?= $prev ?></a>
						<?php endif;
						if ($paged < 200) : ?>
						<a class="button" href="<?= $mainpage ?>?pg=<?= ($paged + 1) ?>"><?= $next ?> &raquo;</a>
						<?php endif; ?>
					<?php endif; ?>
				</div>
				<?php else :
				// ******************* if we must display the content of a single post *********************************
				foreach ($noticias_newswire_feed->posts as $post) : ?>
					<div class="hw-post-single lxnw-post-single nnw-post-single">
						<h1 class="hw-post-title lxnw-post-title nnw-post-title" style="font-family:<?= $font ?>;"><?= $post->title ?></h1>
						<div class="hw-post-date lxnw-post-date nnw-post-date" style="font-family:<?= $font ?>;"><?= $post->date ?></div>
						<div class="hw-post-content lxnw-post-content nnw-post-content" style="font-family:<?= $font ?>;">
							<h2 class="excerpt"><?= $post->summary ?></h2><?= $post->text ?>
						</div>
					</div>
					<div class="hw-clear-both lxnw-clear-both nnw-clear-both"></div>
					<hr />
				<?php break;
				endforeach;
			endif;
			if ($viewmore == "Yes") :
				if ($language == "en")	$viewmore_text = "View More";
				else $viewmore_text = "Ver M&aacute;s";
				?>
				<div class="hw-post-viewmore lxnw-post-viewmore nnw-post-viewmore">
					<a href="<?= $mainpage ?>" style="font-family:<?= $font ?>;<?= $title_color ?>"><?= $viewmore_text ?></a>
				</div>
			<?php endif;
			if ($target != 'sidebar' && $link_post == '') : ?>
				<div class="widget-powered-hma">
					<a href="https://www.hispanicmarketadvisors.com/plug-ins" target="_blank"><?= $powered_by_title ?></a>
				</div>
				<div id="version" style="display: none;"><?= NNW_VERSION ?></div>
			<?php endif; ?>
		</div>
<?php
		$return_value = ob_get_clean();
		return $return_value;
	}

	public function get_light_color()
	{
		return "#edf1f7";
	}

	public function get_dark_color()
	{
		return "#6d798c";
	}

	public function get_noticiasnewswire_title()
	{
		$title = 'noticias-newswire';
		if (!empty($_GET['l'])) {
			$title = $_GET['l'];
		}
		$title = str_ireplace('-', ' ', $title);
		$title = ucwords($title);
		return $title;
	}

	public function get_new_permalink($mainpage, $paged, $post_index, $post_link)
	{
		$new_permalink = str_ireplace($this->noticiasnewswire_domain, '', rtrim($post_link, '/'));
		return $mainpage . '?l=' . $new_permalink;
	}

	/**
	 * Load frontend CSS.
	 * @access  public
	 * @since   2.0.2
	 * @return void
	 */
	public function enqueue_styles()
	{
		wp_register_style($this->_token . '-frontend', esc_url($this->assets_url) . 'css/frontend.css', array(), $this->_version);
		wp_enqueue_style($this->_token . '-frontend');
	}

	public function enqueue_scripts()
	{
		//wp_register_script($this->_token . '-frontend', esc_url($this->assets_url) . 'js/frontend.js', array('jquery'), $this->_version);
		//wp_enqueue_script($this->_token . '-frontend');
	}

	public function admin_enqueue_scripts()
	{
	}

	public function admin_enqueue_styles()
	{
	}

	/**
	 * Main Noticias_Newswire_Plugin Instance
	 *
	 * Ensures only one instance of Noticias_Newswire_Plugin is loaded or can be loaded.
	 *
	 * @since 2.0.2
	 * @static
	 * @see Noticias_Newswire_Plugin()
	 * @return Main Noticias_Newswire_Plugin instance
	 */
	public static function instance($file = '', $version = '2.0.2')
	{
		if (is_null(self::$_instance)) {
			self::$_instance = new self($file, $version);
		}
		return self::$_instance;
	}

	/**
	 * Cloning is forbidden.
	 *
	 * @since 2.0.2
	 */
	public function __clone()
	{
		_doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?'), $this->_version);
	}

	/**
	 * Unserializing instances of this class is forbidden.
	 *
	 * @since 2.0.2
	 */
	public function __wakeup()
	{
		_doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?'), $this->_version);
	}

	/**
	 * Installation. Runs on activation.
	 * @access  public
	 * @since   2.0.2
	 * @return  void
	 */
	public function install()
	{
		$this->_log_version_number();
	}

	/**
	 * Log the plugin version number.
	 * @access  public
	 * @since   2.0.2
	 * @return  void
	 */
	private function _log_version_number()
	{
		update_option($this->_token . '_version', $this->_version);
	}
}

require 'plugin-updates/plugin-update-checker.php';
$ExampleUpdateChecker = PucFactory::buildUpdateChecker(
	'https://www.noticiasnewswire.com/placements/info.json',
	__FILE__,
	'noticias-newswire'
);
